Index: chrome/browser/gtk/reload_button_gtk.cc |
diff --git a/chrome/browser/gtk/reload_button_gtk.cc b/chrome/browser/gtk/reload_button_gtk.cc |
index 8e3cb8fbd18adc627e6543a06c686f1daac6add1..b022cf9466243afbfa0f88d961a2ec0dc45b3557 100644 |
--- a/chrome/browser/gtk/reload_button_gtk.cc |
+++ b/chrome/browser/gtk/reload_button_gtk.cc |
@@ -129,11 +129,10 @@ void ReloadButtonGtk::OnClicked(GtkWidget* sender) { |
GdkModifierType modifier_state; |
gtk_get_current_event_state(&modifier_state); |
guint modifier_state_uint = modifier_state; |
- if (modifier_state_uint & GDK_SHIFT_MASK) { |
+ if (modifier_state_uint & (GDK_SHIFT_MASK | GDK_CONTROL_MASK)) { |
command = IDC_RELOAD_IGNORING_CACHE; |
- // Mask off shift so it isn't interpreted as affecting the disposition |
- // below. |
- modifier_state_uint &= ~GDK_SHIFT_MASK; |
+ // Mask off Shift and Control so they don't affect the disposition below. |
+ modifier_state_uint &= ~(GDK_SHIFT_MASK | GDK_CONTROL_MASK); |
} else { |
command = IDC_RELOAD; |
} |